<?php
/* Mystique/digitalnature */

$mystique_theme_data = get_theme_data(TEMPLATEPATH.'/style.css');

define('THEME_NAME', 'Mystique');
define('THEME_AUTHOR', $mystique_theme_data['Author'] );
define('THEME_URI', $mystique_theme_data['URI'] );
define('THEME_VERSION', trim($mystique_theme_data['Version']) );

if(!defined("PHP_EOL")) define("PHP_EOL", strtoupper(substr(PHP_OS,0,3) == "WIN") ? "\r\n" : "\n");

require_once('lib/settings.php');
require_once('lib/shortcodes.php');
if ($wp_version >= 2.8) require_once('lib/widgets.php');

//if (version_compare(get_mystique_option('theme_version'), THEME_VERSION, '!=')) setup_options();
if (!get_option('mystique')) setup_options();

function getTinyUrl($url) {
    $tinyurl = file_get_contents("http://tinyurl.com/api-create.php?url=".$url);
    return $tinyurl;
}

function init_language(){
	if (class_exists('xili_language')) {
		define('THEME_TEXTDOMAIN','mystique');
		define('THEME_LANGS_FOLDER','/lang');
	} else {
	   load_theme_textdomain('mystique', get_template_directory() . '/lang');
	}
}
add_action ('init', 'init_language');

function isLayoutTemplate(){

//    global $post;
//    $layoutTemplate = get_post_meta($post->ID,'_wp_page_template',true);
//    if (($layoutTemplate=='page-1col.php') || ($layoutTemplate=='page-2col-right.php') || ($layoutTemplate=='page-2col-left.php') || ($layoutTemplate=='page-3col.php') || ($layoutTemplate=='page-3col-left.php') || ($layoutTemplate=='page-3col-right.php')) return true;

    if(is_page_template('page-1col.php') || is_page_template('page-1col.php') || is_page_template('page-2col-right.php') || is_page_template('page-2col-left.php') || is_page_template('page-3col.php') ||is_page_template('page-3col.php') || is_page_template('page-3col-left.php') || is_page_template('page-3col-right.php')) return true;
    return false;
}

// from sandbox theme
// Generates semantic classes for BODY element
function mystique_body_class( $print = true ) {
	global $wp_query, $current_user;

	// Generic semantic classes for what type of content is displayed
	is_front_page()  ? $c[] = 'home'       : null; // For the front page, if set
	is_home()        ? $c[] = 'blog'       : null; // For the blog posts page, if set
	is_archive()     ? $c[] = 'archive'    : null;
	is_date()        ? $c[] = 'date'       : null;
	is_search()      ? $c[] = 'search'     : null;
	is_attachment()  ? $c[] = 'attachment' : null;
	is_404()         ? $c[] = 'not-found'  : null; // CSS does not allow a digit as first character

	// Special classes for BODY element when a single post
	if ( is_single() ) {
		$postID = $wp_query->post->ID;
		the_post();

		// Adds 'single' class and class with the post ID
		$c[] = 'single-post postid-' . $postID;


		// Adds category classes for each category on single posts
		if ( $cats = get_the_category() )
			foreach ( $cats as $cat )
				$c[] = 'category-' . $cat->slug;

		// Adds tag classes for each tags on single posts
		if ( $tags = get_the_tags() )
			foreach ( $tags as $tag )
				$c[] = 'tag-' . $tag->slug;

		// Adds author class for the post author
		$c[] = 'author-' . sanitize_title_with_dashes(strtolower(get_the_author_login()));
		rewind_posts();
	}

	// Author name classes for BODY on author archives
	elseif ( is_author() ) {
		$author = $wp_query->get_queried_object();
		$c[] = 'author';
		$c[] = 'author-' . $author->user_nicename;
	}

	// Category name classes for BODY on category archvies
	elseif ( is_category() ) {
		$cat = $wp_query->get_queried_object();
		$c[] = 'category';
		$c[] = 'category-' . $cat->slug;
	}

	// Tag name classes for BODY on tag archives
	elseif ( is_tag() ) {
		$tags = $wp_query->get_queried_object();
		$c[] = 'tag';
		$c[] = 'tag-' . $tags->slug;
	}

	// Page author for BODY on 'pages'
	elseif ( is_page() ) {
		$pageID = $wp_query->post->ID;
		$page_children = wp_list_pages("child_of=$pageID&echo=0");
		the_post();
		$c[] = 'single-page pageid-' . $pageID;
		$c[] = 'author-' . sanitize_title_with_dashes(strtolower(get_the_author('login')));
		// Checks to see if the page has children and/or is a child page; props to Adam
		if ( $page_children )
			$c[] = 'page-parent';
		if ( $wp_query->post->post_parent )
			$c[] = 'page-child';

		rewind_posts();
	}

	// Search classes for results or no results
	elseif ( is_search() ) {
		the_post();
		if ( have_posts() ) {
			$c[] = 'search-results';
		} else {
			$c[] = 'search-no-results';
		}
		rewind_posts();
	}

    $layout = get_mystique_option('layout');

    // layout
   	if (is_page_template('page-1col.php') || (!isLayoutTemplate() && $layout=="col-1")) $c[] = 'col-1';
   	if (is_page_template('page-2col-left.php') || (!isLayoutTemplate() && $layout=='col-2-left'))  $c[] = 'col-2-left';
   	if (is_page_template('page-2col-right.php') || (!isLayoutTemplate() && $layout=='col-2-right'))  $c[] = 'col-2-right';
   	if (is_page_template('page-3col.php') || (!isLayoutTemplate() && $layout=='col-3'))  $c[] = 'col-3';
   	if (is_page_template('page-3col-left.php') || (!isLayoutTemplate() && $layout=='col-3-left'))  $c[] = 'col-3-left';
   	if (is_page_template('page-3col-right.php') || (!isLayoutTemplate() && $layout=='col-3-right'))  $c[] = 'col-3-right';


	// For when a visitor is logged in while browsing
	if ( $current_user->ID )
		$c[] = 'loggedin';

	// Separates classes with a single space, collates classes for BODY
	$c = join( ' ', apply_filters( 'body_class',  $c ) ); // Available filter: body_class

	// And tada!
	return $print ? print($c) : $c;
}

function strip_content($content, $limit) {
	$content = apply_filters('the_content', $content);

	$content = strip_tags($content);
	$content = str_replace(']]>', ']]&gt;', $content);

	$words = explode(' ', $content, ($limit + 1));
	if(count($words) > $limit) {
		array_pop($words);
		//add a ... at last article when more than limit word count
		return implode(' ', $words) . '...';
	} else {
		//otherwise
		return implode(' ', $words);
	}
}


function strip_string($intLength = 0, $strText = "") {
    if(strlen($strText) > $intLength) {
      $strText = substr($strText,0,$intLength);
      $strText = substr($strText,0,strrpos($strText,' '));
      return $strText.'...';
    }
    else return $strText;
}

function get_first_image() {
 global $post, $posts;
 $first_img = '';
 $output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches);
 $first_img = $matches [1][0];
 return $first_img;
}


function canonical_for_comments() {
    global $cpage, $post;
    if ( $cpage > 1 ) :
        print "\n";
        print "<link rel='canonical' href='";
        print get_permalink( $post->ID );
        print "' />\n";
     endif;
}

if(get_mystique_option('seo'))
 add_action( 'wp_head', 'canonical_for_comments' );


// check if sidebar has widgets
function is_sidebar_active($index = 1) {
  global $wp_registered_sidebars;

  if (is_int($index)): $index = "sidebar-$index";
  else :
  	$index = sanitize_title($index);
  	foreach ((array) $wp_registered_sidebars as $key => $value):
    	if ( sanitize_title($value['name']) == $index):
		 $index = $key;
	     break;
		endif;
	endforeach;
  endif;
  $sidebars_widgets = wp_get_sidebars_widgets();
  if (empty($wp_registered_sidebars[$index]) || !array_key_exists($index, $sidebars_widgets) || !is_array($sidebars_widgets[$index]) || empty($sidebars_widgets[$index]))
    return false;
  else
  	return true;
}


// set up widget areas

if ( function_exists('register_sidebar')) {
    register_sidebar(array(
        'name' => 'Default sidebar',
        'id' => 'sidebar-1',
		'before_widget' => '<li class="block"><div class="block-%2$s" id="instance-%1$s">',
		'after_widget' => '</div></li>',
		'before_title' => '<h3 class="title"><span>',
		'after_title' => '</span></h3><div class="block-div"></div><div class="block-div-arrow"></div>'
    ));

    register_sidebar(array(
        'name' => 'Secondary sidebar',
        'id' => 'sidebar-2',
		'before_widget' => '<li class="block"><div class="block-%2$s" id="instance-%1$s">',
		'after_widget' => '</div></li>',
		'before_title' => '<h3 class="title"><span>',
		'after_title' => '</span></h3><div class="block-div"></div><div class="block-div-arrow"></div>'
    ));

    register_sidebar(array(
        'name' => 'Footer',
        'id' => 'footer-1',
		'before_widget' => '<li class="block block-%2$s" id="instance-%1$s"><div class="block-content">',
		'after_widget' => '</div></li>',
		'before_title' => '<h4 class="title">',
		'after_title' => '</h4>'
    ));

    register_sidebar(array(
        'name' => 'Footer (slide 2)',
        'id' => 'footer-2',
		'before_widget' => '<li class="block block-%2$s" id="instance-%1$s"><div class="block-content">',
		'after_widget' => '</div></li>',
		'before_title' => '<h4 class="title">',
		'after_title' => '</h4>'
    ));


    register_sidebar(array(
        'name' => 'Footer (slide 3)',
        'id' => 'footer-3',
		'before_widget' => '<li class="block block-%2$s" id="instance-%1$s"><div class="block-content">',
		'after_widget' => '</div></li>',
		'before_title' => '<h4 class="title">',
		'after_title' => '</h4>'
    ));


    register_sidebar(array(
        'name' => 'Footer (slide 4)',
        'id' => 'footer-4',
		'before_widget' => '<li class="block block-%2$s" id="instance-%1$s"><div class="block-content">',
		'after_widget' => '</div></li>',
		'before_title' => '<h4 class="title">',
		'after_title' => '</h4>'
    ));

}



function shareThis(){ ?>
   <!-- socialize -->
   <div class="shareThis">
    <a href="#" class="share"><?php _e("Share this post!","mystique"); ?></a>
    <ul class="bubble">
     <a href="http://twitter.com/home?status=<?php the_title(); ?>+-+<?php echo getTinyUrl(get_permalink()); ?>" class="twitter" title="Tweet This!"><span>Twitter</span></a>
     <a href="http://digg.com/submit?phase=2&amp;url=<?php the_permalink(); ?>&amp;title=<?php the_title(); ?>" class="digg" title="Digg this!"><span>Digg</span></a>
     <a href="http://www.facebook.com/share.php?u=<?php the_permalink(); ?>&amp;t=<?php the_title(); ?>" class="facebook" title="Share this on Facebook"><span>Facebook</span></a>
     <a href="http://del.icio.us/post?url=<?php the_permalink(); ?>&amp;title=<?php the_title(); ?>" class="delicious" title="Share this on del.icio.us"><span>Delicious</span></a>
     <a href="http://www.stumbleupon.com/submit?url=<?php the_permalink(); ?>&amp;title=<?php the_title(); ?>" class="stumbleupon" title="Stumbled upon something good? Share it on StumbleUpon"><span>StumbleUpon</span></a>
     <a href="http://www.google.com/bookmarks/mark?op=add&amp;bkmk=<?php the_permalink(); ?>&amp;title=<?php the_title(); ?>" class="google" title="Add this to Google Bookmarks"><span>Google Bookmarks</span></a>
     <a href="http://www.linkedin.com/shareArticle?mini=true&amp;url=<?php the_permalink(); ?>&amp;title=<?php the_title(); ?>&amp;summary=<?php the_excerpt(); ?>&amp;source=<?php bloginfo('name'); ?>" class="linkedin" title="Share this on Linkedin"><span>LinkedIn</span></a>
     <?php /* to do:    <a href="http://buzz.yahoo.com/submit/?submitUrl=<?php the_permalink(); ?>&amp;submitHeadline=<?php the_title(); ?>&amp;submitSummary=YAHOOTEASER&amp;submitCategory=YAHOOCATEGORY&amp;submitAssetType=YAHOOMEDIATYPE" class="yahoo" title="Buzz up!"><span>Yahoo Bookmarks</span></a> */ ?>
     <a href="http://technorati.com/faves?add=<?php the_permalink(); ?>" class="technorati" title="Share this on Technorati"><span>Technorati Favorites</span></a>
    </ul>
   </div>
   <!-- /socialize -->
  <?php
}


// list pings
function list_pings($comment, $args, $depth) {
 $GLOBALS['comment'] = $comment;
 ?>
 <li class="ping" id="comment-<?php comment_ID(); ?>"><a class="websnapr" href="<?php comment_author_url();?>"><?php comment_author(); ?></a>


<?php
} // </li> is added by WP

// list comments
function list_comments($comment, $args, $depth) {
 $GLOBALS['comment'] = $comment;
 global $commentcount;
 if(!$commentcount) { $commentcount = 0; } ?>

  <!-- comment entry -->
  <li <?php if (function_exists('comment_class')) { if (function_exists('get_avatar') && get_option('show_avatars')) print comment_class('withAvatars'); else comment_class(); } else { print 'class="comment';if (function_exists('get_avatar') && get_option('show_avatars')) print ' withAvatars'; print '"';  } ?> id="comment-<?php comment_ID() ?>">
    <div class="comment-head">

      <?php if (function_exists('get_avatar') && get_option('show_avatars')): ?><div class="avatar-box"><?php print get_avatar($comment, 48); ?></div><?php endif; ?>
      <div class="author">
       <?php
        if (get_comment_author_url()) $authorlink='<a class="comment-author websnapr" id="comment-author-'.get_comment_ID().'" href="'.get_comment_author_url().'">'.get_comment_author().'</a>';
        else $authorlink='<b class="comment-author" id="comment-author-'.get_comment_ID().'">'.get_comment_author().'</b>';
        ?><span class="by"><?php printf(__('%s written by %s', 'mystique'), '<a class="comment-id" href="#comment-'.get_comment_ID().'">#'.++$commentcount.'</a>', $authorlink); ?> </span><br />
        <?php print get_comment_time(get_option('date_format')).' - '.get_comment_time(get_option('time_format'));
       ?>
      </div>


      <div class="controls bubble">
        <?php if(comments_open()): ?>
         <?php
          if (function_exists('comment_reply_link'))
            comment_reply_link(array_merge( $args, array('add_below' => 'comment-reply', 'depth' => $depth, 'max_depth' => $args['max_depth'], 'reply_text' => __('Reply','mystique').$my_comment_count))); ?>
          <a class="quote" title="<?php _e('Quote','mystique'); ?>" href="#respond"><?php _e('Quote','mystique'); ?></a>
        <?php endif;
        edit_comment_link('Edit','',''); ?>
      </div>
    </div>
    <div class="comment-body clearfix" id="comment-body-<?php comment_ID() ?>">
      <?php if ($comment->comment_approved == '0'): ?><p class="error"><?php _e('Your comment is awaiting moderation.','mystique'); ?></p><?php endif; ?>
      <div class="comment-text"><?php comment_text(); ?></div>
      <a id="comment-reply-<?php comment_ID() ?>"></a>
    </div>

<?php  // </li> is added by WP
  }
?>